# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepAP242 module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepap242.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepAP242
else:
    import _RWStepAP242

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepAP242.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepAP242.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP242.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP242.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepAP242.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP242.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepAP242.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepAP242.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepAP242.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepAP242.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP242.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP242.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP242.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP242.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP242.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP242.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepAP242.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepAP242:
_RWStepAP242.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepAP242.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepAP242
import OCC.Core.StepBasic
import OCC.Core.StepShape
import OCC.Core.StepGeom
import OCC.Core.StepRepr
import OCC.Core.StepDimTol
import OCC.Core.StepAP214
import OCC.Core.StepVisual
import OCC.Core.TColgp

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepAP242_RWDraughtingModelItemAssociation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP242.RWStepAP242_RWDraughtingModelItemAssociation_swiginit(self, _RWStepAP242.new_RWStepAP242_RWDraughtingModelItemAssociation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP242_DraughtingModelItemAssociation

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWDraughtingModelItemAssociation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP242_DraughtingModelItemAssociation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWDraughtingModelItemAssociation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP242_DraughtingModelItemAssociation

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWDraughtingModelItemAssociation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP242.delete_RWStepAP242_RWDraughtingModelItemAssociation

# Register RWStepAP242_RWDraughtingModelItemAssociation in _RWStepAP242:
_RWStepAP242.RWStepAP242_RWDraughtingModelItemAssociation_swigregister(RWStepAP242_RWDraughtingModelItemAssociation)

class RWStepAP242_RWGeometricItemSpecificUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP242.RWStepAP242_RWGeometricItemSpecificUsage_swiginit(self, _RWStepAP242.new_RWStepAP242_RWGeometricItemSpecificUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP242_GeometricItemSpecificUsage

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWGeometricItemSpecificUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP242_GeometricItemSpecificUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWGeometricItemSpecificUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP242_GeometricItemSpecificUsage

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWGeometricItemSpecificUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP242.delete_RWStepAP242_RWGeometricItemSpecificUsage

# Register RWStepAP242_RWGeometricItemSpecificUsage in _RWStepAP242:
_RWStepAP242.RWStepAP242_RWGeometricItemSpecificUsage_swigregister(RWStepAP242_RWGeometricItemSpecificUsage)

class RWStepAP242_RWIdAttribute(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP242.RWStepAP242_RWIdAttribute_swiginit(self, _RWStepAP242.new_RWStepAP242_RWIdAttribute(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP242_IdAttribute

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWIdAttribute_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP242_IdAttribute
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWIdAttribute_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP242_IdAttribute

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWIdAttribute_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP242.delete_RWStepAP242_RWIdAttribute

# Register RWStepAP242_RWIdAttribute in _RWStepAP242:
_RWStepAP242.RWStepAP242_RWIdAttribute_swigregister(RWStepAP242_RWIdAttribute)

class RWStepAP242_RWItemIdentifiedRepresentationUsage(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepAP242.RWStepAP242_RWItemIdentifiedRepresentationUsage_swiginit(self, _RWStepAP242.new_RWStepAP242_RWItemIdentifiedRepresentationUsage(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP242_ItemIdentifiedRepresentationUsage

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWItemIdentifiedRepresentationUsage_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepAP242_ItemIdentifiedRepresentationUsage
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWItemIdentifiedRepresentationUsage_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP242_ItemIdentifiedRepresentationUsage

        Returns
        -------
        None

        """
        return _RWStepAP242.RWStepAP242_RWItemIdentifiedRepresentationUsage_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP242.delete_RWStepAP242_RWItemIdentifiedRepresentationUsage

# Register RWStepAP242_RWItemIdentifiedRepresentationUsage in _RWStepAP242:
_RWStepAP242.RWStepAP242_RWItemIdentifiedRepresentationUsage_swigregister(RWStepAP242_RWItemIdentifiedRepresentationUsage)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TCollection import *

OSD_PThread = NewType('OSD_PThread', pthread_t)

class OSD_LockType(IntEnum):
	OSD_NoLock: int = ...
	OSD_ReadLock: int = ...
	OSD_WriteLock: int = ...
	OSD_ExclusiveLock: int = ...
OSD_NoLock = OSD_LockType.OSD_NoLock
OSD_ReadLock = OSD_LockType.OSD_ReadLock
OSD_WriteLock = OSD_LockType.OSD_WriteLock
OSD_ExclusiveLock = OSD_LockType.OSD_ExclusiveLock

class OSD_LoadMode(IntEnum):
	OSD_RTLD_LAZY: int = ...
	OSD_RTLD_NOW: int = ...
OSD_RTLD_LAZY = OSD_LoadMode.OSD_RTLD_LAZY
OSD_RTLD_NOW = OSD_LoadMode.OSD_RTLD_NOW

class OSD_OpenMode(IntEnum):
	OSD_ReadOnly: int = ...
	OSD_WriteOnly: int = ...
	OSD_ReadWrite: int = ...
OSD_ReadOnly = OSD_OpenMode.OSD_ReadOnly
OSD_WriteOnly = OSD_OpenMode.OSD_WriteOnly
OSD_ReadWrite = OSD_OpenMode.OSD_ReadWrite

class OSD_OEMType(IntEnum):
	OSD_Unavailable: int = ...
	OSD_SUN: int = ...
	OSD_DEC: int = ...
	OSD_SGI: int = ...
	OSD_NEC: int = ...
	OSD_MAC: int = ...
	OSD_PC: int = ...
	OSD_HP: int = ...
	OSD_IBM: int = ...
	OSD_VAX: int = ...
	OSD_LIN: int = ...
	OSD_AIX: int = ...
OSD_Unavailable = OSD_OEMType.OSD_Unavailable
OSD_SUN = OSD_OEMType.OSD_SUN
OSD_DEC = OSD_OEMType.OSD_DEC
OSD_SGI = OSD_OEMType.OSD_SGI
OSD_NEC = OSD_OEMType.OSD_NEC
OSD_MAC = OSD_OEMType.OSD_MAC
OSD_PC = OSD_OEMType.OSD_PC
OSD_HP = OSD_OEMType.OSD_HP
OSD_IBM = OSD_OEMType.OSD_IBM
OSD_VAX = OSD_OEMType.OSD_VAX
OSD_LIN = OSD_OEMType.OSD_LIN
OSD_AIX = OSD_OEMType.OSD_AIX

class OSD_WhoAmI(IntEnum):
	OSD_WDirectory: int = ...
	OSD_WDirectoryIterator: int = ...
	OSD_WEnvironment: int = ...
	OSD_WFile: int = ...
	OSD_WFileNode: int = ...
	OSD_WFileIterator: int = ...
	OSD_WPath: int = ...
	OSD_WProcess: int = ...
	OSD_WProtection: int = ...
	OSD_WHost: int = ...
	OSD_WDisk: int = ...
	OSD_WChronometer: int = ...
	OSD_WTimer: int = ...
	OSD_WPackage: int = ...
	OSD_WEnvironmentIterator: int = ...
OSD_WDirectory = OSD_WhoAmI.OSD_WDirectory
OSD_WDirectoryIterator = OSD_WhoAmI.OSD_WDirectoryIterator
OSD_WEnvironment = OSD_WhoAmI.OSD_WEnvironment
OSD_WFile = OSD_WhoAmI.OSD_WFile
OSD_WFileNode = OSD_WhoAmI.OSD_WFileNode
OSD_WFileIterator = OSD_WhoAmI.OSD_WFileIterator
OSD_WPath = OSD_WhoAmI.OSD_WPath
OSD_WProcess = OSD_WhoAmI.OSD_WProcess
OSD_WProtection = OSD_WhoAmI.OSD_WProtection
OSD_WHost = OSD_WhoAmI.OSD_WHost
OSD_WDisk = OSD_WhoAmI.OSD_WDisk
OSD_WChronometer = OSD_WhoAmI.OSD_WChronometer
OSD_WTimer = OSD_WhoAmI.OSD_WTimer
OSD_WPackage = OSD_WhoAmI.OSD_WPackage
OSD_WEnvironmentIterator = OSD_WhoAmI.OSD_WEnvironmentIterator

class OSD_SysType(IntEnum):
	OSD_Unknown: int = ...
	OSD_Default: int = ...
	OSD_UnixBSD: int = ...
	OSD_UnixSystemV: int = ...
	OSD_VMS: int = ...
	OSD_OS2: int = ...
	OSD_OSF: int = ...
	OSD_MacOs: int = ...
	OSD_Taligent: int = ...
	OSD_WindowsNT: int = ...
	OSD_LinuxREDHAT: int = ...
	OSD_Aix: int = ...
OSD_Unknown = OSD_SysType.OSD_Unknown
OSD_Default = OSD_SysType.OSD_Default
OSD_UnixBSD = OSD_SysType.OSD_UnixBSD
OSD_UnixSystemV = OSD_SysType.OSD_UnixSystemV
OSD_VMS = OSD_SysType.OSD_VMS
OSD_OS2 = OSD_SysType.OSD_OS2
OSD_OSF = OSD_SysType.OSD_OSF
OSD_MacOs = OSD_SysType.OSD_MacOs
OSD_Taligent = OSD_SysType.OSD_Taligent
OSD_WindowsNT = OSD_SysType.OSD_WindowsNT
OSD_LinuxREDHAT = OSD_SysType.OSD_LinuxREDHAT
OSD_Aix = OSD_SysType.OSD_Aix

class OSD_KindFile(IntEnum):
	OSD_FILE: int = ...
	OSD_DIRECTORY: int = ...
	OSD_LINK: int = ...
	OSD_SOCKET: int = ...
	OSD_UNKNOWN: int = ...
OSD_FILE = OSD_KindFile.OSD_FILE
OSD_DIRECTORY = OSD_KindFile.OSD_DIRECTORY
OSD_LINK = OSD_KindFile.OSD_LINK
OSD_SOCKET = OSD_KindFile.OSD_SOCKET
OSD_UNKNOWN = OSD_KindFile.OSD_UNKNOWN

class OSD_SignalMode(IntEnum):
	OSD_SignalMode_AsIs: int = ...
	OSD_SignalMode_Set: int = ...
	OSD_SignalMode_SetUnhandled: int = ...
	OSD_SignalMode_Unset: int = ...
OSD_SignalMode_AsIs = OSD_SignalMode.OSD_SignalMode_AsIs
OSD_SignalMode_Set = OSD_SignalMode.OSD_SignalMode_Set
OSD_SignalMode_SetUnhandled = OSD_SignalMode.OSD_SignalMode_SetUnhandled
OSD_SignalMode_Unset = OSD_SignalMode.OSD_SignalMode_Unset

class OSD_FromWhere(IntEnum):
	OSD_FromBeginning: int = ...
	OSD_FromHere: int = ...
	OSD_FromEnd: int = ...
OSD_FromBeginning = OSD_FromWhere.OSD_FromBeginning
OSD_FromHere = OSD_FromWhere.OSD_FromHere
OSD_FromEnd = OSD_FromWhere.OSD_FromEnd

class OSD_SingleProtection(IntEnum):
	OSD_None: int = ...
	OSD_R: int = ...
	OSD_W: int = ...
	OSD_RW: int = ...
	OSD_X: int = ...
	OSD_RX: int = ...
	OSD_WX: int = ...
	OSD_RWX: int = ...
	OSD_D: int = ...
	OSD_RD: int = ...
	OSD_WD: int = ...
	OSD_RWD: int = ...
	OSD_XD: int = ...
	OSD_RXD: int = ...
	OSD_WXD: int = ...
	OSD_RWXD: int = ...
OSD_None = OSD_SingleProtection.OSD_None
OSD_R = OSD_SingleProtection.OSD_R
OSD_W = OSD_SingleProtection.OSD_W
OSD_RW = OSD_SingleProtection.OSD_RW
OSD_X = OSD_SingleProtection.OSD_X
OSD_RX = OSD_SingleProtection.OSD_RX
OSD_WX = OSD_SingleProtection.OSD_WX
OSD_RWX = OSD_SingleProtection.OSD_RWX
OSD_D = OSD_SingleProtection.OSD_D
OSD_RD = OSD_SingleProtection.OSD_RD
OSD_WD = OSD_SingleProtection.OSD_WD
OSD_RWD = OSD_SingleProtection.OSD_RWD
OSD_XD = OSD_SingleProtection.OSD_XD
OSD_RXD = OSD_SingleProtection.OSD_RXD
OSD_WXD = OSD_SingleProtection.OSD_WXD
OSD_RWXD = OSD_SingleProtection.OSD_RWXD

#classnotwrapped
class OSD_Timer: ...

#classnotwrapped
class OSD_PerfMeter: ...

#classnotwrapped
class OSD_Disk: ...

#classnotwrapped
class OSD_Protection: ...

#classnotwrapped
class OSD_MemInfo: ...

#classnotwrapped
class OSD_DirectoryIterator: ...

#classnotwrapped
class OSD_Chronometer: ...

#classnotwrapped
class OSD_ThreadPool: ...

#classnotwrapped
class OSD_SharedLibrary: ...

#classnotwrapped
class OSD_Error: ...

#classnotwrapped
class OSD_Host: ...

#classnotwrapped
class OSD_Parallel: ...

#classnotwrapped
class OSD_Directory: ...

#classnotwrapped
class OSD_Path: ...

#classnotwrapped
class OSD_Process: ...

#classnotwrapped
class OSD_MAllocHook: ...

#classnotwrapped
class OSD_FileNode: ...

#classnotwrapped
class OSD_File: ...

#classnotwrapped
class OSD_FileIterator: ...

#classnotwrapped
class OSD_Thread: ...

#classnotwrapped
class OSD_Environment: ...

#classnotwrapped
class OSD: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *

#the following typedef cannot be wrapped as is
TShort_Array2OfShortReal = NewType('TShort_Array2OfShortReal', Any)

class TShort_Array1OfShortReal:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> float: ...
    def __setitem__(self, index: int, value: float) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[float]: ...
    def next(self) -> float: ...
    __next__ = next
    def Init(self, theValue: float) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> float: ...
    def Last(self) -> float: ...
    def Value(self, theIndex: int) -> float: ...
    def SetValue(self, theIndex: int, theValue: float) -> None: ...

class TShort_SequenceOfShortReal:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> float: ...
    def Last(self) -> float: ...
    def Length(self) -> int: ...
    def Append(self, theItem: float) -> float: ...
    def Prepend(self, theItem: float) -> float: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> float: ...
    def SetValue(self, theIndex: int, theValue: float) -> None: ...

# harray1 classes

class TShort_HArray1OfShortReal(TShort_Array1OfShortReal, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> TShort_Array1OfShortReal: ...

# harray2 classes

class TShort_HArray2OfShortReal(TShort_Array2OfShortReal, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: TShort_Array2OfShortReal) -> None: ...
    def Array2(self) -> TShort_Array2OfShortReal: ...

# hsequence classes

class TShort_HSequenceOfShortReal(TShort_SequenceOfShortReal, Standard_Transient):
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: TShort_SequenceOfShortReal) -> None: ...
    def Sequence(self) -> TShort_SequenceOfShortReal: ...
    def Append(self, theSequence: TShort_SequenceOfShortReal) -> None: ...





# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
BRepFilletAPI module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_brepfilletapi.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _BRepFilletAPI
else:
    import _BRepFilletAPI

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _BRepFilletAPI.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _BRepFilletAPI.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepFilletAPI.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _BRepFilletAPI.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _BRepFilletAPI.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _BRepFilletAPI.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _BRepFilletAPI.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _BRepFilletAPI.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _BRepFilletAPI.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _BRepFilletAPI.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepFilletAPI.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _BRepFilletAPI.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _BRepFilletAPI.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepFilletAPI.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _BRepFilletAPI.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _BRepFilletAPI.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _BRepFilletAPI.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _BRepFilletAPI:
_BRepFilletAPI.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _BRepFilletAPI.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BRepBuilderAPI
import OCC.Core.Geom
import OCC.Core.gp
import OCC.Core.TColStd
import OCC.Core.TCollection
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.TopTools
import OCC.Core.BRepTools
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.Geom2d
import OCC.Core.BRep
import OCC.Core.Poly
import OCC.Core.TShort
import OCC.Core.ChFiDS
import OCC.Core.Adaptor3d
import OCC.Core.Adaptor2d
import OCC.Core.math
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.Law
import OCC.Core.ChFi2d
import OCC.Core.TopOpeBRepBuild
import OCC.Core.TopOpeBRepDS
import OCC.Core.TopOpeBRepTool
import OCC.Core.BRepClass3d
import OCC.Core.IntCurveSurface
import OCC.Core.Intf
import OCC.Core.IntSurf
import OCC.Core.IntCurvesFace
import OCC.Core.TopExp
import OCC.Core.Extrema
import OCC.Core.ChFi3d
import OCC.Core.BRepBlend
import OCC.Core.BlendFunc
import OCC.Core.Convert
import OCC.Core.Blend
import OCC.Core.Approx
import OCC.Core.AppCont
import OCC.Core.AppParCurves
import OCC.Core.AppBlend
import OCC.Core.GeomFill
import OCC.Core.TColGeom

from enum import IntEnum
from OCC.Core.Exception import *



class BRepFilletAPI_LocalOperation(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    def Abscissa(self, *args) -> "Standard_Real":
        r"""
        Returns the abscissa of the vertex v on the contour of index ic.

        Parameters
        ----------
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        float

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Abscissa(self, *args)

    def Add(self, *args) -> "void":
        r"""
        Adds a contour in the builder (builds a contour of tangent edges).

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Add(self, *args)

    def Closed(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the contour of index ic is closed.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Closed(self, *args)

    def ClosedAndTangent(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the contour of index ic is closed an tangent.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_ClosedAndTangent(self, *args)

    def Contour(self, *args) -> "Standard_Integer":
        r"""
        Returns the index of the contour containing the edge e, returns 0 if e doesn't belong to any contour.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Contour(self, *args)

    def Edge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the edge j in the contour i.

        Parameters
        ----------
        I: int
        J: int

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Edge(self, *args)

    def FirstVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns the first vertex of the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_FirstVertex(self, *args)

    def LastVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns the last vertex of the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_LastVertex(self, *args)

    def Length(self, *args) -> "Standard_Real":
        r"""
        Returns the length the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        float

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Length(self, *args)

    def NbContours(self, *args) -> "Standard_Integer":
        r"""
        Number of contours.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_NbContours(self, *args)

    def NbEdges(self, *args) -> "Standard_Integer":
        r"""
        Number of edges in the contour i.

        Parameters
        ----------
        I: int

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_NbEdges(self, *args)

    def NbSurf(self, *args) -> "Standard_Integer":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_NbSurf(self, *args)

    def RelativeAbscissa(self, *args) -> "Standard_Real":
        r"""
        Returns the relative abscissa([0.,1.]) of the vertex v on the contour of index ic.

        Parameters
        ----------
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        float

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_RelativeAbscissa(self, *args)

    def Remove(self, *args) -> "void":
        r"""
        Remove the contour containing the edge e.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Remove(self, *args)

    def Reset(self, *args) -> "void":
        r"""
        Reset all the fields updated by build operation and leave the algorithm in the same state than before build call. it allows contours and radius modifications to build the result another time.

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Reset(self, *args)

    def ResetContour(self, *args) -> "void":
        r"""
        Reset the contour of index ic, there is nomore information in the contour.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_ResetContour(self, *args)

    def Sect(self, *args) -> "opencascade::handle< ChFiDS_SecHArray1 >":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int
        IS: int

        Returns
        -------
        opencascade::handle<ChFiDS_SecHArray1>

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Sect(self, *args)

    def Simulate(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_LocalOperation_Simulate(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFilletAPI.delete_BRepFilletAPI_LocalOperation

# Register BRepFilletAPI_LocalOperation in _BRepFilletAPI:
_BRepFilletAPI.BRepFilletAPI_LocalOperation_swigregister(BRepFilletAPI_LocalOperation)

class BRepFilletAPI_MakeFillet2d(OCC.Core.BRepBuilderAPI.BRepBuilderAPI_MakeShape):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes an empty algorithm for computing fillets and chamfers. the face on which the fillets and chamfers are built is defined using the init function. the vertices on which fillets or chamfers are built are defined using the addfillet or addchamfer function. warning the status of the initialization, as given by the status function, can be one of the following: - chfi2d_ready if the initialization is correct, - chfi2d_notplanar if f is not planar, - chfi2d_noface if f is a null face.

        Returns
        -------
        None
        Initializes an algorithm for computing fillets and chamfers on the face f. the vertices on which fillets or chamfers are built are defined using the addfillet or addchamfer function. warning the status of the initialization, as given by the status function, can be one of the following: - chfi2d_ready if the initialization is correct, - chfi2d_notplanar if f is not planar, - chfi2d_noface if f is a null face.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None

        """
        _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_swiginit(self, _BRepFilletAPI.new_BRepFilletAPI_MakeFillet2d(*args))

    def AddChamfer(self, *args) -> "TopoDS_Edge":
        r"""
        Adds a chamfer on the face modified by this algorithm between the two adjacent edges e1 and e2, where the extremities of the chamfer are on e1 and e2 at distances d1 and d2 respectively in cases where the edges are not rectilinear, distances are measured using the curvilinear abscissa of the edges and the angle is measured with respect to the tangent at the corresponding point. the angle ang is given in radians. this function returns the chamfer and builds the resulting face.

        Parameters
        ----------
        E1: TopoDS_Edge
        E2: TopoDS_Edge
        D1: float
        D2: float

        Returns
        -------
        TopoDS_Edge
        Adds a chamfer on the face modified by this algorithm between the two edges connected by the vertex v, where e is one of the two edges. the chamfer makes an angle ang with e and one of its extremities is on e at distance d from v. in cases where the edges are not rectilinear, distances are measured using the curvilinear abscissa of the edges and the angle is measured with respect to the tangent at the corresponding point. the angle ang is given in radians. this function returns the chamfer and builds the resulting face. warning the status of the construction, as given by the status function, can be one of the following: - chfi2d_isdone if the chamfer is built, - chfi2d_parameterserror if d1, d2, d or ang is less than or equal to zero, - chfi2d_connexionerror if: - the edge e, e1 or e2 does not belong to the initial face, or - the edges e1 and e2 are not adjacent, or - the vertex v is not one of the limit points of the edge e, - chfi2d_computationerror if the parameters of the chamfer are too large to build a chamfer between the two adjacent edges, - chfi2d_notauthorized if: - the edge e1, e2 or one of the two edges connected to v is a fillet or chamfer, or - a curve other than a straight line or an arc of a circle is used as e, e1 or e2. do not use the returned chamfer if the status of the construction is not chfi2d_isdone.

        Parameters
        ----------
        E: TopoDS_Edge
        V: TopoDS_Vertex
        D: float
        Ang: float

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_AddChamfer(self, *args)

    def AddFillet(self, *args) -> "TopoDS_Edge":
        r"""
        Adds a fillet of radius radius between the two edges adjacent to the vertex v on the face modified by this algorithm. the two edges do not need to be rectilinear. this function returns the fillet and builds the resulting face. warning the status of the construction, as given by the status function, can be one of the following: - chfi2d_isdone if the fillet is built, - chfi2d_connexionerror if v does not belong to the initial face, - chfi2d_computationerror if radius is too large to build a fillet between the two adjacent edges, - chfi2d_notauthorized - if one of the two edges connected to v is a fillet or chamfer, or - if a curve other than a straight line or an arc of a circle is used as e, e1 or e2. do not use the returned fillet if the status of the construction is not chfi2d_isdone. exceptions standard_negativevalue if radius is less than or equal to zero.

        Parameters
        ----------
        V: TopoDS_Vertex
        Radius: float

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_AddFillet(self, *args)

    def BasisEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the basis edge on the face modified by this algorithm from which the chamfered or filleted edge e is built. if e has not been modified, this function returns e. warning e is returned if it does not belong to the initial face.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_BasisEdge(self, *args)

    def ChamferEdges(self, *args) -> "TopTools_SequenceOfShape const &":
        r"""
        Returns the table of chamfers on the face modified by this algorithm.

        Returns
        -------
        TopTools_SequenceOfShape

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_ChamferEdges(self, *args)

    def DescendantEdge(self, *args) -> "TopoDS_Edge const":
        r"""
        Returns the chamfered or filleted edge built from the edge e on the face modified by this algorithm. if e has not been modified, this function returns e. exceptions standard_nosuchobject if the edge e does not belong to the initial face.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_DescendantEdge(self, *args)

    def FilletEdges(self, *args) -> "TopTools_SequenceOfShape const &":
        r"""
        Returns the table of fillets on the face modified by this algorithm.

        Returns
        -------
        TopTools_SequenceOfShape

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_FilletEdges(self, *args)

    def HasDescendant(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_HasDescendant(self, *args)

    def Init(self, *args) -> "void":
        r"""
        Initializes this algorithm for constructing fillets or chamfers with the face f. warning the status of the initialization, as given by the status function, can be one of the following: - chfi2d_ready if the initialization is correct, - chfi2d_notplanar if f is not planar, - chfi2d_noface if f is a null face.

        Parameters
        ----------
        F: TopoDS_Face

        Returns
        -------
        None
        This initialize method allow to init the builder from a face <refface> and another face <modface> which derive from <refface>. this is usefull to modify a fillet or a chamfer already created on <modface> .

        Parameters
        ----------
        RefFace: TopoDS_Face
        ModFace: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_Init(self, *args)

    def IsModified(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the edge e on the face modified by this algorithm is chamfered or filleted. warning returns false if e does not belong to the face modified by this algorithm.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_IsModified(self, *args)

    def ModifyChamfer(self, *args) -> "TopoDS_Edge":
        r"""
        Modifies the chamfer chamfer on the face modified by this algorithm, where: e1 and e2 are the two adjacent edges on which chamfer is already built; the extremities of the new chamfer are on e1 and e2 at distances d1 and d2 respectively.

        Parameters
        ----------
        Chamfer: TopoDS_Edge
        E1: TopoDS_Edge
        E2: TopoDS_Edge
        D1: float
        D2: float

        Returns
        -------
        TopoDS_Edge
        Modifies the chamfer chamfer on the face modified by this algorithm, where: e is one of the two adjacent edges on which chamfer is already built; the new chamfer makes an angle ang with e and one of its extremities is on e at distance d from the vertex on which the chamfer is built. in cases where the edges are not rectilinear, the distances are measured using the curvilinear abscissa of the edges and the angle is measured with respect to the tangent at the corresponding point. the angle ang is given in radians. this function returns the new chamfer and modifies the existing face. warning the status of the construction, as given by the status function, can be one of the following: - chfi2d_isdone if the chamfer is built, - chfi2d_parameterserror if d1, d2, d or ang is less than or equal to zero, - chfi2d_connexionerror if: - the edge e, e1, e2 or chamfer does not belong to the existing face, or - the edges e1 and e2 are not adjacent, - chfi2d_computationerror if the parameters of the chamfer are too large to build a chamfer between the two adjacent edges, - chfi2d_notauthorized if e1 or e2 is a fillet or chamfer. do not use the returned chamfer if the status of the construction is not chfi2d_isdone.

        Parameters
        ----------
        Chamfer: TopoDS_Edge
        E: TopoDS_Edge
        D: float
        Ang: float

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_ModifyChamfer(self, *args)

    def ModifyFillet(self, *args) -> "TopoDS_Edge":
        r"""
        Assigns the radius radius to the fillet fillet already built on the face modified by this algorithm. this function returns the new fillet and modifies the existing face. warning the status of the construction, as given by the status function, can be one of the following: - chfi2d_isdone if the new fillet is built, - chfi2d_connexionerror if fillet does not belong to the existing face, - chfi2d_computationerror if radius is too large to build a fillet between the two adjacent edges. do not use the returned fillet if the status of the construction is not chfi2d_isdone. exceptions standard_negativevalue if radius is less than or equal to zero.

        Parameters
        ----------
        Fillet: TopoDS_Edge
        Radius: float

        Returns
        -------
        TopoDS_Edge

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_ModifyFillet(self, *args)

    def NbChamfer(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of chamfers on the face modified by this algorithm.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_NbChamfer(self, *args)

    def NbCurves(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of new curves after the shape creation.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_NbCurves(self, *args)

    def NbFillet(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of fillets on the face modified by this algorithm.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_NbFillet(self, *args)

    def NewEdges(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Return the edges created for curve i.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_NewEdges(self, *args)

    def RemoveChamfer(self, *args) -> "TopoDS_Vertex":
        r"""
        Removes the chamfer chamfer already built on the face modified by this algorithm. this function returns the vertex connecting the two adjacent edges of chamfer and modifies the existing face. warning - the returned vertex is only valid if the status function returns chfi2d_isdone. - a null vertex is returned if the edge chamfer does not belong to the initial face.

        Parameters
        ----------
        Chamfer: TopoDS_Edge

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_RemoveChamfer(self, *args)

    def RemoveFillet(self, *args) -> "TopoDS_Vertex":
        r"""
        Removes the fillet fillet already built on the face modified by this algorithm. this function returns the vertex connecting the two adjacent edges of fillet and modifies the existing face. warning - the returned vertex is only valid if the status function returns chfi2d_isdone. - a null vertex is returned if the edge fillet does not belong to the initial face.

        Parameters
        ----------
        Fillet: TopoDS_Edge

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_RemoveFillet(self, *args)

    def Status(self, *args) -> "ChFi2d_ConstructionError":
        r"""
        No available documentation.

        Returns
        -------
        ChFi2d_ConstructionError

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet2d_Status(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFilletAPI.delete_BRepFilletAPI_MakeFillet2d

# Register BRepFilletAPI_MakeFillet2d in _BRepFilletAPI:
_BRepFilletAPI.BRepFilletAPI_MakeFillet2d_swigregister(BRepFilletAPI_MakeFillet2d)

class BRepFilletAPI_MakeChamfer(BRepFilletAPI_LocalOperation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes an algorithm for computing chamfers on the shape s. the edges on which chamfers are built are defined using the add function.

        Parameters
        ----------
        S: TopoDS_Shape

        Returns
        -------
        None

        """
        _BRepFilletAPI.BRepFilletAPI_MakeChamfer_swiginit(self, _BRepFilletAPI.new_BRepFilletAPI_MakeChamfer(*args))

    def Add(self, *args) -> "void":
        r"""
        Adds edge e to the table of edges used by this algorithm to build chamfers, where the parameters of the chamfer must be set after the.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None
        Adds edge e to the table of edges used by this algorithm to build chamfers, where the parameters of the chamfer are given by the distance dis (symmetric chamfer). the add function results in a contour being built by propagation from the edge e (i.e. the contour contains at least this edge). this contour is composed of edges of the shape which are tangential to one another and which delimit two series of tangential faces, with one series of faces being located on either side of the contour. warning nothing is done if edge e or the face f does not belong to the initial shape.

        Parameters
        ----------
        Dis: float
        E: TopoDS_Edge

        Returns
        -------
        None
        Adds edge e to the table of edges used by this algorithm to build chamfers, where the parameters of the chamfer are given by the two distances dis1 and dis2; the face f identifies the side where dis1 is measured. the add function results in a contour being built by propagation from the edge e (i.e. the contour contains at least this edge). this contour is composed of edges of the shape which are tangential to one another and which delimit two series of tangential faces, with one series of faces being located on either side of the contour. warning nothing is done if edge e or the face f does not belong to the initial shape.

        Parameters
        ----------
        Dis1: float
        Dis2: float
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_Add(self, *args)

    def AddDA(self, *args) -> "void":
        r"""
        Adds a fillet contour in the builder (builds a contour of tangent edges to <e> and sets the distance <dis1> and angle <angle> ( parameters of the chamfer ) ).

        Parameters
        ----------
        Dis: float
        Angle: float
        E: TopoDS_Edge
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_AddDA(self, *args)

    def Builder(self, *args) -> "opencascade::handle< TopOpeBRepBuild_HBuilder >":
        r"""
        Returns the internal filleting algorithm.

        Returns
        -------
        opencascade::handle<TopOpeBRepBuild_HBuilder>

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_Builder(self, *args)

    def Dists(self, *args) -> "void":
        r"""
        Returns the distances dis1 and dis2 which give the parameters of the chamfer along the contour of index ic in the internal data structure of this algorithm. warning -1. is returned if ic is outside the bounds of the table of contours.

        Parameters
        ----------
        IC: int

        Returns
        -------
        Dis1: float
        Dis2: float

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_Dists(self, *args)

    def GetDist(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int

        Returns
        -------
        Dis: float

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_GetDist(self, *args)

    def GetDistAngle(self, *args) -> "void":
        r"""
        Gives the distances <dis> and <angle> of the fillet contour of index <ic> in the ds.

        Parameters
        ----------
        IC: int

        Returns
        -------
        Dis: float
        Angle: float

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_GetDistAngle(self, *args)

    def IsDistanceAngle(self, *args) -> "Standard_Boolean":
        r"""
        Return true if chamfer is made with distance and angle false else.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_IsDistanceAngle(self, *args)

    def IsSymetric(self, *args) -> "Standard_Boolean":
        r"""
        Return true if chamfer symetric false else.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_IsSymetric(self, *args)

    def IsTwoDistances(self, *args) -> "Standard_Boolean":
        r"""
        Return true if chamfer is made with two distances false else.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_IsTwoDistances(self, *args)

    def SetDist(self, *args) -> "void":
        r"""
        Sets the distances dis1 and dis2 which give the parameters of the chamfer along the contour of index ic generated using the add function in the internal data structure of this algorithm. the face f identifies the side where dis1 is measured. warning nothing is done if either the edge e or the face f does not belong to the initial shape.

        Parameters
        ----------
        Dis: float
        IC: int
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_SetDist(self, *args)

    def SetDistAngle(self, *args) -> "void":
        r"""
        Set the distance <dis> and <angle> of the fillet contour of index <ic> in the ds with <dis> on <f>. if the face <f> is not one of common faces of an edge of the contour <ic>.

        Parameters
        ----------
        Dis: float
        Angle: float
        IC: int
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_SetDistAngle(self, *args)

    def SetDists(self, *args) -> "void":
        r"""
        Sets the distances dis1 and dis2 which give the parameters of the chamfer along the contour of index ic generated using the add function in the internal data structure of this algorithm. the face f identifies the side where dis1 is measured. warning nothing is done if either the edge e or the face f does not belong to the initial shape.

        Parameters
        ----------
        Dis1: float
        Dis2: float
        IC: int
        F: TopoDS_Face

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_SetDists(self, *args)

    def SetMode(self, *args) -> "void":
        r"""
        Sets the mode of chamfer.

        Parameters
        ----------
        theMode: ChFiDS_ChamfMode

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeChamfer_SetMode(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFilletAPI.delete_BRepFilletAPI_MakeChamfer

# Register BRepFilletAPI_MakeChamfer in _BRepFilletAPI:
_BRepFilletAPI.BRepFilletAPI_MakeChamfer_swigregister(BRepFilletAPI_MakeChamfer)

class BRepFilletAPI_MakeFillet(BRepFilletAPI_LocalOperation):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Initializes the computation of the fillets. <fshape> sets the type of fillet surface. the default value is chfi3d_rational (classical nurbs representation of circles). chfi3d_quasiangular corresponds to a nurbs representation of circles which parameterisation matches the circle one. chfi3d_polynomial corresponds to a polynomial representation of circles.

        Parameters
        ----------
        S: TopoDS_Shape
        FShape: ChFi3d_FilletShape,optional
        	default value is ChFi3d_Rational

        Returns
        -------
        None

        """
        _BRepFilletAPI.BRepFilletAPI_MakeFillet_swiginit(self, _BRepFilletAPI.new_BRepFilletAPI_MakeFillet(*args))

    def Add(self, *args) -> "void":
        r"""
        Adds a fillet contour in the builder (builds a contour of tangent edges). the radius must be set after.

        Parameters
        ----------
        E: TopoDS_Edge

        Returns
        -------
        None
        Adds a fillet description in the builder - builds a contour of tangent edges, - sets the radius.

        Parameters
        ----------
        Radius: float
        E: TopoDS_Edge

        Returns
        -------
        None
        Adds a fillet description in the builder - builds a contour of tangent edges, - sets a linear radius evolution law between the first and last vertex of the spine.

        Parameters
        ----------
        R1: float
        R2: float
        E: TopoDS_Edge

        Returns
        -------
        None
        Adds a fillet description in the builder - builds a contour of tangent edges, - sest the radius evolution law.

        Parameters
        ----------
        L: Law_Function
        E: TopoDS_Edge

        Returns
        -------
        None
        Adds a fillet description in the builder - builds a contour of tangent edges, - sets the radius evolution law interpolating the values given in the array uandr : //! p2d.x() = relative parameter on the spine [0,1] p2d.y() = value of the radius.

        Parameters
        ----------
        UandR: TColgp_Array1OfPnt2d
        E: TopoDS_Edge

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_Add(self, *args)

    def BadShape(self, *args) -> "TopoDS_Shape":
        r"""
        If (hasresult()) returns the partial result.

        Returns
        -------
        TopoDS_Shape

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_BadShape(self, *args)

    def Builder(self, *args) -> "opencascade::handle< TopOpeBRepBuild_HBuilder >":
        r"""
        Returns the internal topology building algorithm.

        Returns
        -------
        opencascade::handle<TopOpeBRepBuild_HBuilder>

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_Builder(self, *args)

    def ComputedSurface(self, *args) -> "opencascade::handle< Geom_Surface >":
        r"""
        Returns the surface number is concerning the contour ic.

        Parameters
        ----------
        IC: int
        IS: int

        Returns
        -------
        opencascade::handle<Geom_Surface>

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_ComputedSurface(self, *args)

    def FaultyContour(self, *args) -> "Standard_Integer":
        r"""
        For each i in [1.. nbfaultycontours] returns the index ic of the contour where the computation of the fillet failed. the method nbedges(ic) gives the number of edges in the contour ic the method edge(ic,ie) gives the edge number ie of the contour ic.

        Parameters
        ----------
        I: int

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_FaultyContour(self, *args)

    def FaultyVertex(self, *args) -> "TopoDS_Vertex":
        r"""
        Returns the vertex where the computation failed.

        Parameters
        ----------
        IV: int

        Returns
        -------
        TopoDS_Vertex

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_FaultyVertex(self, *args)

    def GetBounds(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        F: float
        L: float

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_GetBounds(self, *args)

    def GetFilletShape(self, *args) -> "ChFi3d_FilletShape":
        r"""
        Returns the type of fillet shape built by this algorithm.

        Returns
        -------
        ChFi3d_FilletShape

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_GetFilletShape(self, *args)

    def GetLaw(self, *args) -> "opencascade::handle< Law_Function >":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        opencascade::handle<Law_Function>

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_GetLaw(self, *args)

    def HasResult(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if a part of the result has been computed if the filling in a corner failed a shape with a hole is returned.

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_HasResult(self, *args)

    def IsConstant(self, *args) -> "Standard_Boolean":
        r"""
        Returns true if the radius of the fillet along the contour of index ic in the internal data structure of this algorithm is constant, warning false is returned if ic is outside the bounds of the table of contours or if e does not belong to the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        bool
        Returns true if the radius of the fillet along the edge e of the contour of index ic in the internal data structure of this algorithm is constant. warning false is returned if ic is outside the bounds of the table of contours or if e does not belong to the contour of index ic.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        bool

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_IsConstant(self, *args)

    def NbComputedSurfaces(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of surfaces which have been computed on the contour ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_NbComputedSurfaces(self, *args)

    def NbFaultyContours(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of contours where the computation of the fillet failed.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_NbFaultyContours(self, *args)

    def NbFaultyVertices(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of vertices where the computation failed.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_NbFaultyVertices(self, *args)

    def NbSurfaces(self, *args) -> "Standard_Integer":
        r"""
        Returns the number of surfaces after the shape creation.

        Returns
        -------
        int

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_NbSurfaces(self, *args)

    def NewFaces(self, *args) -> "TopTools_ListOfShape const &":
        r"""
        Return the faces created for surface <i>.

        Parameters
        ----------
        I: int

        Returns
        -------
        TopTools_ListOfShape

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_NewFaces(self, *args)

    def Radius(self, *args) -> "Standard_Real":
        r"""
        Returns the radius of the fillet along the contour of index ic in the internal data structure of this algorithm warning - use this function only if the radius is constant. - -1. is returned if ic is outside the bounds of the table of contours or if e does not belong to the contour of index ic.

        Parameters
        ----------
        IC: int

        Returns
        -------
        float
        Returns the radius of the fillet along the edge e of the contour of index ic in the internal data structure of this algorithm. warning - use this function only if the radius is constant. - -1 is returned if ic is outside the bounds of the table of contours or if e does not belong to the contour of index ic.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        float

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_Radius(self, *args)

    def SetContinuity(self, *args) -> "void":
        r"""
        Changes the parameters of continiuity internalcontinuity to produce fillet'surfaces with an continuity ci (i=0,1 or 2). by defaultinternalcontinuity = geomabs_c1. angulartolerance is the g1 tolerance between fillet and support'faces.

        Parameters
        ----------
        InternalContinuity: GeomAbs_Shape
        AngularTolerance: float

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_SetContinuity(self, *args)

    def SetFilletShape(self, *args) -> "void":
        r"""
        Assigns fshape as the type of fillet shape built by this algorithm.

        Parameters
        ----------
        FShape: ChFi3d_FilletShape

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_SetFilletShape(self, *args)

    def SetLaw(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        IC: int
        E: TopoDS_Edge
        L: Law_Function

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_SetLaw(self, *args)

    def SetParams(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        Tang: float
        Tesp: float
        T2d: float
        TApp3d: float
        TolApp2d: float
        Fleche: float

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_SetParams(self, *args)

    def SetRadius(self, *args) -> "void":
        r"""
        Sets the parameters of the fillet along the contour of index ic generated using the add function in the internal data structure of this algorithm, where radius is the radius of the fillet.

        Parameters
        ----------
        Radius: float
        IC: int
        IinC: int

        Returns
        -------
        None
        Sets the parameters of the fillet along the contour of index ic generated using the add function in the internal data structure of this algorithm, where the radius of the fillet evolves according to a linear evolution law defined from r1 to r2, between the first and last vertices of the contour of index ic.

        Parameters
        ----------
        R1: float
        R2: float
        IC: int
        IinC: int

        Returns
        -------
        None
        Sets the parameters of the fillet along the contour of index ic generated using the add function in the internal data structure of this algorithm, where the radius of the fillet evolves according to the evolution law l, between the first and last vertices of the contour of index ic.

        Parameters
        ----------
        L: Law_Function
        IC: int
        IinC: int

        Returns
        -------
        None
        Sets the parameters of the fillet along the contour of index ic generated using the add function in the internal data structure of this algorithm, where the radius of the fillet evolves according to the evolution law which interpolates the set of parameter and radius pairs given in the array uandr as follows: - the x coordinate of a point in uandr defines a relative parameter on the contour (i.e. a parameter between 0 and 1), - the y coordinate of a point in uandr gives the corresponding value of the radius, and the radius evolves between the first and last vertices of the contour of index ic.

        Parameters
        ----------
        UandR: TColgp_Array1OfPnt2d
        IC: int
        IinC: int

        Returns
        -------
        None
        Assigns radius as the radius of the fillet on the edge e.

        Parameters
        ----------
        Radius: float
        IC: int
        E: TopoDS_Edge

        Returns
        -------
        None
        No available documentation.

        Parameters
        ----------
        Radius: float
        IC: int
        V: TopoDS_Vertex

        Returns
        -------
        None

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_SetRadius(self, *args)

    def StripeStatus(self, *args) -> "ChFiDS_ErrorStatus":
        r"""
        Returns the status concerning the contour ic in case of error chfids_ok : the computation is ok chfids_startsolfailure : the computation can't start, perhaps the the radius is too big chfids_twistedsurface : the computation failed because of a twisted surface chfids_walkingfailure : there is a problem in the walking chfids_error: other error different from above.

        Parameters
        ----------
        IC: int

        Returns
        -------
        ChFiDS_ErrorStatus

        """
        return _BRepFilletAPI.BRepFilletAPI_MakeFillet_StripeStatus(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _BRepFilletAPI.delete_BRepFilletAPI_MakeFillet

# Register BRepFilletAPI_MakeFillet in _BRepFilletAPI:
_BRepFilletAPI.BRepFilletAPI_MakeFillet_swigregister(BRepFilletAPI_MakeFillet)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TopoDS import *
from OCC.Core.GeomAbs import *
from OCC.Core.Geom import *
from OCC.Core.TopLoc import *
from OCC.Core.Poly import *
from OCC.Core.gp import *
from OCC.Core.Geom2d import *
from OCC.Core.TopAbs import *


class BRep_ListOfCurveRepresentation:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class BRep_ListOfPointRepresentation:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class BRep_Builder(TopoDS_Builder):
	@overload
	def Continuity(self, E: TopoDS_Edge, F1: TopoDS_Face, F2: TopoDS_Face, C: GeomAbs_Shape) -> None: ...
	@overload
	def Continuity(self, E: TopoDS_Edge, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location, C: GeomAbs_Shape) -> None: ...
	def Degenerated(self, E: TopoDS_Edge, D: bool) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, C: Geom_Curve, Tol: float) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, C: Geom_Curve, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, P: Poly_Polygon3D) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, N: Poly_PolygonOnTriangulation, T: Poly_Triangulation) -> None: ...
	@overload
	def MakeEdge(self, E: TopoDS_Edge, N: Poly_PolygonOnTriangulation, T: Poly_Triangulation, L: TopLoc_Location) -> None: ...
	@overload
	def MakeFace(self, F: TopoDS_Face) -> None: ...
	@overload
	def MakeFace(self, F: TopoDS_Face, S: Geom_Surface, Tol: float) -> None: ...
	@overload
	def MakeFace(self, F: TopoDS_Face, S: Geom_Surface, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def MakeFace(self, F: TopoDS_Face, T: Poly_Triangulation) -> None: ...
	@overload
	def MakeVertex(self, V: TopoDS_Vertex) -> None: ...
	@overload
	def MakeVertex(self, V: TopoDS_Vertex, P: gp_Pnt, Tol: float) -> None: ...
	def NaturalRestriction(self, F: TopoDS_Face, N: bool) -> None: ...
	@overload
	def Range(self, E: TopoDS_Edge, First: float, Last: float, Only3d: Optional[bool] = False) -> None: ...
	@overload
	def Range(self, E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location, First: float, Last: float) -> None: ...
	@overload
	def Range(self, E: TopoDS_Edge, F: TopoDS_Face, First: float, Last: float) -> None: ...
	def SameParameter(self, E: TopoDS_Edge, S: bool) -> None: ...
	def SameRange(self, E: TopoDS_Edge, S: bool) -> None: ...
	@overload
	def Transfert(self, Ein: TopoDS_Edge, Eout: TopoDS_Edge) -> None: ...
	@overload
	def Transfert(self, Ein: TopoDS_Edge, Eout: TopoDS_Edge, Vin: TopoDS_Vertex, Vout: TopoDS_Vertex) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C: Geom_Curve, Tol: float) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C: Geom_Curve, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C: Geom2d_Curve, F: TopoDS_Face, Tol: float) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C1: Geom2d_Curve, C2: Geom2d_Curve, F: TopoDS_Face, Tol: float) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location, Tol: float, Pf: gp_Pnt2d, Pl: gp_Pnt2d) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C1: Geom2d_Curve, C2: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, C1: Geom2d_Curve, C2: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location, Tol: float, Pf: gp_Pnt2d, Pl: gp_Pnt2d) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, P: Poly_Polygon3D) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, P: Poly_Polygon3D, L: TopLoc_Location) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, N: Poly_PolygonOnTriangulation, T: Poly_Triangulation) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, N: Poly_PolygonOnTriangulation, T: Poly_Triangulation, L: TopLoc_Location) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, N1: Poly_PolygonOnTriangulation, N2: Poly_PolygonOnTriangulation, T: Poly_Triangulation) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, N1: Poly_PolygonOnTriangulation, N2: Poly_PolygonOnTriangulation, T: Poly_Triangulation, L: TopLoc_Location) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, P: Poly_Polygon2D, S: TopoDS_Face) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, P: Poly_Polygon2D, S: Geom_Surface, T: TopLoc_Location) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, P1: Poly_Polygon2D, P2: Poly_Polygon2D, S: TopoDS_Face) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, P1: Poly_Polygon2D, P2: Poly_Polygon2D, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	@overload
	def UpdateEdge(self, E: TopoDS_Edge, Tol: float) -> None: ...
	@overload
	def UpdateFace(self, F: TopoDS_Face, S: Geom_Surface, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def UpdateFace(self, F: TopoDS_Face, T: Poly_Triangulation) -> None: ...
	@overload
	def UpdateFace(self, F: TopoDS_Face, Tol: float) -> None: ...
	@overload
	def UpdateVertex(self, V: TopoDS_Vertex, P: gp_Pnt, Tol: float) -> None: ...
	@overload
	def UpdateVertex(self, V: TopoDS_Vertex, P: float, E: TopoDS_Edge, Tol: float) -> None: ...
	@overload
	def UpdateVertex(self, V: TopoDS_Vertex, P: float, E: TopoDS_Edge, F: TopoDS_Face, Tol: float) -> None: ...
	@overload
	def UpdateVertex(self, V: TopoDS_Vertex, P: float, E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location, Tol: float) -> None: ...
	@overload
	def UpdateVertex(self, Ve: TopoDS_Vertex, U: float, V: float, F: TopoDS_Face, Tol: float) -> None: ...
	@overload
	def UpdateVertex(self, V: TopoDS_Vertex, Tol: float) -> None: ...

class BRep_CurveRepresentation(Standard_Transient):
	@overload
	def Continuity(self) -> GeomAbs_Shape: ...
	@overload
	def Continuity(self, C: GeomAbs_Shape) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	@overload
	def Curve3D(self) -> Geom_Curve: ...
	@overload
	def Curve3D(self, C: Geom_Curve) -> None: ...
	def IsCurve3D(self) -> bool: ...
	def IsCurveOnClosedSurface(self) -> bool: ...
	@overload
	def IsCurveOnSurface(self) -> bool: ...
	@overload
	def IsCurveOnSurface(self, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	def IsPolygon3D(self) -> bool: ...
	def IsPolygonOnClosedSurface(self) -> bool: ...
	def IsPolygonOnClosedTriangulation(self) -> bool: ...
	@overload
	def IsPolygonOnSurface(self) -> bool: ...
	@overload
	def IsPolygonOnSurface(self, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def IsPolygonOnTriangulation(self) -> bool: ...
	@overload
	def IsPolygonOnTriangulation(self, T: Poly_Triangulation, L: TopLoc_Location) -> bool: ...
	@overload
	def IsRegularity(self) -> bool: ...
	@overload
	def IsRegularity(self, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location) -> bool: ...
	@overload
	def Location(self) -> TopLoc_Location: ...
	@overload
	def Location(self, L: TopLoc_Location) -> None: ...
	def Location2(self) -> TopLoc_Location: ...
	@overload
	def PCurve(self) -> Geom2d_Curve: ...
	@overload
	def PCurve(self, C: Geom2d_Curve) -> None: ...
	@overload
	def PCurve2(self) -> Geom2d_Curve: ...
	@overload
	def PCurve2(self, C: Geom2d_Curve) -> None: ...
	@overload
	def Polygon(self) -> Poly_Polygon2D: ...
	@overload
	def Polygon(self, P: Poly_Polygon2D) -> None: ...
	@overload
	def Polygon2(self) -> Poly_Polygon2D: ...
	@overload
	def Polygon2(self, P: Poly_Polygon2D) -> None: ...
	@overload
	def Polygon3D(self) -> Poly_Polygon3D: ...
	@overload
	def Polygon3D(self, P: Poly_Polygon3D) -> None: ...
	@overload
	def PolygonOnTriangulation(self) -> Poly_PolygonOnTriangulation: ...
	@overload
	def PolygonOnTriangulation(self, P: Poly_PolygonOnTriangulation) -> None: ...
	@overload
	def PolygonOnTriangulation2(self) -> Poly_PolygonOnTriangulation: ...
	@overload
	def PolygonOnTriangulation2(self, P2: Poly_PolygonOnTriangulation) -> None: ...
	def Surface(self) -> Geom_Surface: ...
	def Surface2(self) -> Geom_Surface: ...
	def Triangulation(self) -> Poly_Triangulation: ...

class BRep_PointRepresentation(Standard_Transient):
	@overload
	def Curve(self) -> Geom_Curve: ...
	@overload
	def Curve(self, C: Geom_Curve) -> None: ...
	@overload
	def IsPointOnCurve(self) -> bool: ...
	@overload
	def IsPointOnCurve(self, C: Geom_Curve, L: TopLoc_Location) -> bool: ...
	@overload
	def IsPointOnCurveOnSurface(self) -> bool: ...
	@overload
	def IsPointOnCurveOnSurface(self, PC: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def IsPointOnSurface(self) -> bool: ...
	@overload
	def IsPointOnSurface(self, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def Location(self) -> TopLoc_Location: ...
	@overload
	def Location(self, L: TopLoc_Location) -> None: ...
	@overload
	def PCurve(self) -> Geom2d_Curve: ...
	@overload
	def PCurve(self, C: Geom2d_Curve) -> None: ...
	@overload
	def Parameter(self) -> float: ...
	@overload
	def Parameter(self, P: float) -> None: ...
	@overload
	def Parameter2(self) -> float: ...
	@overload
	def Parameter2(self, P: float) -> None: ...
	@overload
	def Surface(self) -> Geom_Surface: ...
	@overload
	def Surface(self, S: Geom_Surface) -> None: ...

class BRep_TEdge(TopoDS_TEdge):
	def __init__(self) -> None: ...
	def ChangeCurves(self) -> BRep_ListOfCurveRepresentation: ...
	def Curves(self) -> BRep_ListOfCurveRepresentation: ...
	@overload
	def Degenerated(self) -> bool: ...
	@overload
	def Degenerated(self, S: bool) -> None: ...
	def EmptyCopy(self) -> TopoDS_TShape: ...
	@overload
	def SameParameter(self) -> bool: ...
	@overload
	def SameParameter(self, S: bool) -> None: ...
	@overload
	def SameRange(self) -> bool: ...
	@overload
	def SameRange(self, S: bool) -> None: ...
	@overload
	def Tolerance(self) -> float: ...
	@overload
	def Tolerance(self, T: float) -> None: ...
	def UpdateTolerance(self, T: float) -> None: ...

class BRep_TFace(TopoDS_TFace):
	def __init__(self) -> None: ...
	def EmptyCopy(self) -> TopoDS_TShape: ...
	@overload
	def Location(self) -> TopLoc_Location: ...
	@overload
	def Location(self, L: TopLoc_Location) -> None: ...
	@overload
	def NaturalRestriction(self) -> bool: ...
	@overload
	def NaturalRestriction(self, N: bool) -> None: ...
	@overload
	def Surface(self) -> Geom_Surface: ...
	@overload
	def Surface(self, S: Geom_Surface) -> None: ...
	@overload
	def Tolerance(self) -> float: ...
	@overload
	def Tolerance(self, T: float) -> None: ...
	@overload
	def Triangulation(self) -> Poly_Triangulation: ...
	@overload
	def Triangulation(self, T: Poly_Triangulation) -> None: ...

class BRep_TVertex(TopoDS_TVertex):
	def __init__(self) -> None: ...
	def ChangePoints(self) -> BRep_ListOfPointRepresentation: ...
	def EmptyCopy(self) -> TopoDS_TShape: ...
	@overload
	def Pnt(self) -> gp_Pnt: ...
	@overload
	def Pnt(self, P: gp_Pnt) -> None: ...
	def Points(self) -> BRep_ListOfPointRepresentation: ...
	@overload
	def Tolerance(self) -> float: ...
	@overload
	def Tolerance(self, T: float) -> None: ...
	def UpdateTolerance(self, T: float) -> None: ...

class BRep_Tool:
	@overload
	@staticmethod
	def Continuity(E: TopoDS_Edge, F1: TopoDS_Face, F2: TopoDS_Face) -> GeomAbs_Shape: ...
	@overload
	@staticmethod
	def Continuity(E: TopoDS_Edge, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location) -> GeomAbs_Shape: ...
	@overload
	@staticmethod
	def Curve(E: TopoDS_Edge, L: TopLoc_Location) -> Tuple[Geom_Curve, float, float]: ...
	@overload
	@staticmethod
	def Curve(E: TopoDS_Edge) -> Tuple[Geom_Curve, float, float]: ...
	@staticmethod
	def CurveOnPlane(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location) -> Tuple[Geom2d_Curve, float, float]: ...
	@overload
	@staticmethod
	def CurveOnSurface(E: TopoDS_Edge, F: TopoDS_Face, theIsStored: Optional[bool] = None) -> Tuple[Geom2d_Curve, float, float]: ...
	@overload
	@staticmethod
	def CurveOnSurface(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location, theIsStored: Optional[bool] = None) -> Tuple[Geom2d_Curve, float, float]: ...
	@overload
	@staticmethod
	def CurveOnSurface(E: TopoDS_Edge, C: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def CurveOnSurface(E: TopoDS_Edge, C: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location, Index: int) -> Tuple[float, float]: ...
	@staticmethod
	def Degenerated(E: TopoDS_Edge) -> bool: ...
	@overload
	@staticmethod
	def HasContinuity(E: TopoDS_Edge, F1: TopoDS_Face, F2: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def HasContinuity(E: TopoDS_Edge, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location) -> bool: ...
	@overload
	@staticmethod
	def HasContinuity(E: TopoDS_Edge) -> bool: ...
	@overload
	@staticmethod
	def IsClosed(S: TopoDS_Shape) -> bool: ...
	@overload
	@staticmethod
	def IsClosed(E: TopoDS_Edge, F: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def IsClosed(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	@staticmethod
	def IsClosed(E: TopoDS_Edge, T: Poly_Triangulation, L: TopLoc_Location) -> bool: ...
	@overload
	@staticmethod
	def IsGeometric(F: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def IsGeometric(E: TopoDS_Edge) -> bool: ...
	@staticmethod
	def MaxContinuity(theEdge: TopoDS_Edge) -> GeomAbs_Shape: ...
	@staticmethod
	def MaxTolerance(theShape: TopoDS_Shape, theSubShape: TopAbs_ShapeEnum) -> float: ...
	@staticmethod
	def NaturalRestriction(F: TopoDS_Face) -> bool: ...
	@overload
	@staticmethod
	def Parameter(theV: TopoDS_Vertex, theE: TopoDS_Edge) -> Tuple[bool, float]: ...
	@overload
	@staticmethod
	def Parameter(V: TopoDS_Vertex, E: TopoDS_Edge) -> float: ...
	@overload
	@staticmethod
	def Parameter(V: TopoDS_Vertex, E: TopoDS_Edge, F: TopoDS_Face) -> float: ...
	@overload
	@staticmethod
	def Parameter(V: TopoDS_Vertex, E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location) -> float: ...
	@staticmethod
	def Parameters(V: TopoDS_Vertex, F: TopoDS_Face) -> gp_Pnt2d: ...
	@staticmethod
	def Pnt(V: TopoDS_Vertex) -> gp_Pnt: ...
	@staticmethod
	def Polygon3D(E: TopoDS_Edge, L: TopLoc_Location) -> Poly_Polygon3D: ...
	@overload
	@staticmethod
	def PolygonOnSurface(E: TopoDS_Edge, F: TopoDS_Face) -> Poly_Polygon2D: ...
	@overload
	@staticmethod
	def PolygonOnSurface(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location) -> Poly_Polygon2D: ...
	@overload
	@staticmethod
	def PolygonOnSurface(E: TopoDS_Edge, C: Poly_Polygon2D, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	@overload
	@staticmethod
	def PolygonOnSurface(E: TopoDS_Edge, C: Poly_Polygon2D, S: Geom_Surface, L: TopLoc_Location, Index: int) -> None: ...
	@overload
	@staticmethod
	def PolygonOnTriangulation(E: TopoDS_Edge, T: Poly_Triangulation, L: TopLoc_Location) -> Poly_PolygonOnTriangulation: ...
	@overload
	@staticmethod
	def PolygonOnTriangulation(E: TopoDS_Edge, P: Poly_PolygonOnTriangulation, T: Poly_Triangulation, L: TopLoc_Location) -> None: ...
	@overload
	@staticmethod
	def PolygonOnTriangulation(E: TopoDS_Edge, P: Poly_PolygonOnTriangulation, T: Poly_Triangulation, L: TopLoc_Location, Index: int) -> None: ...
	@overload
	@staticmethod
	def Range(E: TopoDS_Edge) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Range(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location) -> Tuple[float, float]: ...
	@overload
	@staticmethod
	def Range(E: TopoDS_Edge, F: TopoDS_Face) -> Tuple[float, float]: ...
	@staticmethod
	def SameParameter(E: TopoDS_Edge) -> bool: ...
	@staticmethod
	def SameRange(E: TopoDS_Edge) -> bool: ...
	@overload
	@staticmethod
	def SetUVPoints(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location, PFirst: gp_Pnt2d, PLast: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def SetUVPoints(E: TopoDS_Edge, F: TopoDS_Face, PFirst: gp_Pnt2d, PLast: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def Surface(F: TopoDS_Face, L: TopLoc_Location) -> Geom_Surface: ...
	@overload
	@staticmethod
	def Surface(F: TopoDS_Face) -> Geom_Surface: ...
	@overload
	@staticmethod
	def Tolerance(F: TopoDS_Face) -> float: ...
	@overload
	@staticmethod
	def Tolerance(E: TopoDS_Edge) -> float: ...
	@overload
	@staticmethod
	def Tolerance(V: TopoDS_Vertex) -> float: ...
	@staticmethod
	def Triangulation(F: TopoDS_Face, L: TopLoc_Location) -> Poly_Triangulation: ...
	@overload
	@staticmethod
	def UVPoints(E: TopoDS_Edge, S: Geom_Surface, L: TopLoc_Location, PFirst: gp_Pnt2d, PLast: gp_Pnt2d) -> None: ...
	@overload
	@staticmethod
	def UVPoints(E: TopoDS_Edge, F: TopoDS_Face, PFirst: gp_Pnt2d, PLast: gp_Pnt2d) -> None: ...

class BRep_CurveOn2Surfaces(BRep_CurveRepresentation):
	def __init__(self, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location, C: GeomAbs_Shape) -> None: ...
	@overload
	def Continuity(self) -> GeomAbs_Shape: ...
	@overload
	def Continuity(self, C: GeomAbs_Shape) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	@overload
	def IsRegularity(self) -> bool: ...
	@overload
	def IsRegularity(self, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location) -> bool: ...
	def Location2(self) -> TopLoc_Location: ...
	def Surface(self) -> Geom_Surface: ...
	def Surface2(self) -> Geom_Surface: ...

class BRep_GCurve(BRep_CurveRepresentation):
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	@overload
	def First(self) -> float: ...
	@overload
	def First(self, F: float) -> None: ...
	@overload
	def Last(self) -> float: ...
	@overload
	def Last(self, L: float) -> None: ...
	def Range(self) -> Tuple[float, float]: ...
	def SetRange(self, First: float, Last: float) -> None: ...
	def Update(self) -> None: ...

class BRep_PointOnCurve(BRep_PointRepresentation):
	def __init__(self, P: float, C: Geom_Curve, L: TopLoc_Location) -> None: ...
	@overload
	def Curve(self) -> Geom_Curve: ...
	@overload
	def Curve(self, C: Geom_Curve) -> None: ...
	@overload
	def IsPointOnCurve(self) -> bool: ...
	@overload
	def IsPointOnCurve(self, C: Geom_Curve, L: TopLoc_Location) -> bool: ...

class BRep_PointsOnSurface(BRep_PointRepresentation):
	@overload
	def Surface(self) -> Geom_Surface: ...
	@overload
	def Surface(self, S: Geom_Surface) -> None: ...

class BRep_Polygon3D(BRep_CurveRepresentation):
	def __init__(self, P: Poly_Polygon3D, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	def IsPolygon3D(self) -> bool: ...
	@overload
	def Polygon3D(self) -> Poly_Polygon3D: ...
	@overload
	def Polygon3D(self, P: Poly_Polygon3D) -> None: ...

class BRep_PolygonOnSurface(BRep_CurveRepresentation):
	def __init__(self, P: Poly_Polygon2D, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	@overload
	def IsPolygonOnSurface(self) -> bool: ...
	@overload
	def IsPolygonOnSurface(self, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def Polygon(self) -> Poly_Polygon2D: ...
	@overload
	def Polygon(self, P: Poly_Polygon2D) -> None: ...
	def Surface(self) -> Geom_Surface: ...

class BRep_PolygonOnTriangulation(BRep_CurveRepresentation):
	def __init__(self, P: Poly_PolygonOnTriangulation, T: Poly_Triangulation, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	@overload
	def IsPolygonOnTriangulation(self) -> bool: ...
	@overload
	def IsPolygonOnTriangulation(self, T: Poly_Triangulation, L: TopLoc_Location) -> bool: ...
	@overload
	def PolygonOnTriangulation(self, P: Poly_PolygonOnTriangulation) -> None: ...
	@overload
	def PolygonOnTriangulation(self) -> Poly_PolygonOnTriangulation: ...
	def Triangulation(self) -> Poly_Triangulation: ...

class BRep_Curve3D(BRep_GCurve):
	def __init__(self, C: Geom_Curve, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	@overload
	def Curve3D(self) -> Geom_Curve: ...
	@overload
	def Curve3D(self, C: Geom_Curve) -> None: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	def IsCurve3D(self) -> bool: ...

class BRep_CurveOnSurface(BRep_GCurve):
	def __init__(self, PC: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	def D0(self, U: float, P: gp_Pnt) -> None: ...
	@overload
	def IsCurveOnSurface(self) -> bool: ...
	@overload
	def IsCurveOnSurface(self, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def PCurve(self) -> Geom2d_Curve: ...
	@overload
	def PCurve(self, C: Geom2d_Curve) -> None: ...
	def SetUVPoints(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Surface(self) -> Geom_Surface: ...
	def UVPoints(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Update(self) -> None: ...

class BRep_PointOnCurveOnSurface(BRep_PointsOnSurface):
	def __init__(self, P: float, C: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	@overload
	def IsPointOnCurveOnSurface(self) -> bool: ...
	@overload
	def IsPointOnCurveOnSurface(self, PC: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def PCurve(self) -> Geom2d_Curve: ...
	@overload
	def PCurve(self, C: Geom2d_Curve) -> None: ...

class BRep_PointOnSurface(BRep_PointsOnSurface):
	def __init__(self, P1: float, P2: float, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	@overload
	def IsPointOnSurface(self) -> bool: ...
	@overload
	def IsPointOnSurface(self, S: Geom_Surface, L: TopLoc_Location) -> bool: ...
	@overload
	def Parameter2(self) -> float: ...
	@overload
	def Parameter2(self, P: float) -> None: ...

class BRep_PolygonOnClosedSurface(BRep_PolygonOnSurface):
	def __init__(self, P1: Poly_Polygon2D, P2: Poly_Polygon2D, S: Geom_Surface, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	def IsPolygonOnClosedSurface(self) -> bool: ...
	@overload
	def Polygon2(self) -> Poly_Polygon2D: ...
	@overload
	def Polygon2(self, P: Poly_Polygon2D) -> None: ...

class BRep_PolygonOnClosedTriangulation(BRep_PolygonOnTriangulation):
	def __init__(self, P1: Poly_PolygonOnTriangulation, P2: Poly_PolygonOnTriangulation, Tr: Poly_Triangulation, L: TopLoc_Location) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	def IsPolygonOnClosedTriangulation(self) -> bool: ...
	@overload
	def PolygonOnTriangulation2(self, P2: Poly_PolygonOnTriangulation) -> None: ...
	@overload
	def PolygonOnTriangulation2(self) -> Poly_PolygonOnTriangulation: ...

class BRep_CurveOnClosedSurface(BRep_CurveOnSurface):
	def __init__(self, PC1: Geom2d_Curve, PC2: Geom2d_Curve, S: Geom_Surface, L: TopLoc_Location, C: GeomAbs_Shape) -> None: ...
	@overload
	def Continuity(self) -> GeomAbs_Shape: ...
	@overload
	def Continuity(self, C: GeomAbs_Shape) -> None: ...
	def Copy(self) -> BRep_CurveRepresentation: ...
	def IsCurveOnClosedSurface(self) -> bool: ...
	@overload
	def IsRegularity(self) -> bool: ...
	@overload
	def IsRegularity(self, S1: Geom_Surface, S2: Geom_Surface, L1: TopLoc_Location, L2: TopLoc_Location) -> bool: ...
	def Location2(self) -> TopLoc_Location: ...
	@overload
	def PCurve2(self) -> Geom2d_Curve: ...
	@overload
	def PCurve2(self, C: Geom2d_Curve) -> None: ...
	def SetUVPoints2(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Surface2(self) -> Geom_Surface: ...
	def UVPoints2(self, P1: gp_Pnt2d, P2: gp_Pnt2d) -> None: ...
	def Update(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

BRep_Tool_Continuity = BRep_Tool.Continuity
BRep_Tool_Continuity = BRep_Tool.Continuity
BRep_Tool_Curve = BRep_Tool.Curve
BRep_Tool_Curve = BRep_Tool.Curve
BRep_Tool_CurveOnPlane = BRep_Tool.CurveOnPlane
BRep_Tool_CurveOnSurface = BRep_Tool.CurveOnSurface
BRep_Tool_CurveOnSurface = BRep_Tool.CurveOnSurface
BRep_Tool_CurveOnSurface = BRep_Tool.CurveOnSurface
BRep_Tool_CurveOnSurface = BRep_Tool.CurveOnSurface
BRep_Tool_Degenerated = BRep_Tool.Degenerated
BRep_Tool_HasContinuity = BRep_Tool.HasContinuity
BRep_Tool_HasContinuity = BRep_Tool.HasContinuity
BRep_Tool_HasContinuity = BRep_Tool.HasContinuity
BRep_Tool_IsClosed = BRep_Tool.IsClosed
BRep_Tool_IsClosed = BRep_Tool.IsClosed
BRep_Tool_IsClosed = BRep_Tool.IsClosed
BRep_Tool_IsClosed = BRep_Tool.IsClosed
BRep_Tool_IsGeometric = BRep_Tool.IsGeometric
BRep_Tool_IsGeometric = BRep_Tool.IsGeometric
BRep_Tool_MaxContinuity = BRep_Tool.MaxContinuity
BRep_Tool_MaxTolerance = BRep_Tool.MaxTolerance
BRep_Tool_NaturalRestriction = BRep_Tool.NaturalRestriction
BRep_Tool_Parameter = BRep_Tool.Parameter
BRep_Tool_Parameter = BRep_Tool.Parameter
BRep_Tool_Parameter = BRep_Tool.Parameter
BRep_Tool_Parameter = BRep_Tool.Parameter
BRep_Tool_Parameters = BRep_Tool.Parameters
BRep_Tool_Pnt = BRep_Tool.Pnt
BRep_Tool_Polygon3D = BRep_Tool.Polygon3D
BRep_Tool_PolygonOnSurface = BRep_Tool.PolygonOnSurface
BRep_Tool_PolygonOnSurface = BRep_Tool.PolygonOnSurface
BRep_Tool_PolygonOnSurface = BRep_Tool.PolygonOnSurface
BRep_Tool_PolygonOnSurface = BRep_Tool.PolygonOnSurface
BRep_Tool_PolygonOnTriangulation = BRep_Tool.PolygonOnTriangulation
BRep_Tool_PolygonOnTriangulation = BRep_Tool.PolygonOnTriangulation
BRep_Tool_PolygonOnTriangulation = BRep_Tool.PolygonOnTriangulation
BRep_Tool_Range = BRep_Tool.Range
BRep_Tool_Range = BRep_Tool.Range
BRep_Tool_Range = BRep_Tool.Range
BRep_Tool_SameParameter = BRep_Tool.SameParameter
BRep_Tool_SameRange = BRep_Tool.SameRange
BRep_Tool_SetUVPoints = BRep_Tool.SetUVPoints
BRep_Tool_SetUVPoints = BRep_Tool.SetUVPoints
BRep_Tool_Surface = BRep_Tool.Surface
BRep_Tool_Surface = BRep_Tool.Surface
BRep_Tool_Tolerance = BRep_Tool.Tolerance
BRep_Tool_Tolerance = BRep_Tool.Tolerance
BRep_Tool_Tolerance = BRep_Tool.Tolerance
BRep_Tool_Triangulation = BRep_Tool.Triangulation
BRep_Tool_UVPoints = BRep_Tool.UVPoints
BRep_Tool_UVPoints = BRep_Tool.UVPoints



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.TColStd import *
from OCC.Core.GeomAbs import *
from OCC.Core.AdvApprox import *
from OCC.Core.Geom import *
from OCC.Core.gp import *
from OCC.Core.TColgp import *


class AdvApp2Var_SequenceOfNode:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class AdvApp2Var_SequenceOfPatch:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class AdvApp2Var_SequenceOfStrip:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> AdvApp2Var_Strip: ...
    def Last(self) -> AdvApp2Var_Strip: ...
    def Length(self) -> int: ...
    def Append(self, theItem: AdvApp2Var_Strip) -> AdvApp2Var_Strip: ...
    def Prepend(self, theItem: AdvApp2Var_Strip) -> AdvApp2Var_Strip: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> AdvApp2Var_Strip: ...
    def SetValue(self, theIndex: int, theValue: AdvApp2Var_Strip) -> None: ...

class AdvApp2Var_Strip:
    def __init__(self) -> None: ...
    def __len__(self) -> int: ...
    def Size(self) -> int: ...
    def Clear(self) -> None: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Length(self) -> int: ...
    def Append(self, theItem: False) -> False: ...
    def Prepend(self, theItem: False) -> False: ...
    def RemoveFirst(self) -> None: ...
    def Reverse(self) -> None: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class AdvApp2Var_CriterionRepartition(IntEnum):
	AdvApp2Var_Regular: int = ...
	AdvApp2Var_Incremental: int = ...
AdvApp2Var_Regular = AdvApp2Var_CriterionRepartition.AdvApp2Var_Regular
AdvApp2Var_Incremental = AdvApp2Var_CriterionRepartition.AdvApp2Var_Incremental

class AdvApp2Var_CriterionType(IntEnum):
	AdvApp2Var_Absolute: int = ...
	AdvApp2Var_Relative: int = ...
AdvApp2Var_Absolute = AdvApp2Var_CriterionType.AdvApp2Var_Absolute
AdvApp2Var_Relative = AdvApp2Var_CriterionType.AdvApp2Var_Relative

class AdvApp2Var_ApproxAFunc2Var:
	@overload
	def __init__(self, Num1DSS: int, Num2DSS: int, Num3DSS: int, OneDTol: TColStd_HArray1OfReal, TwoDTol: TColStd_HArray1OfReal, ThreeDTol: TColStd_HArray1OfReal, OneDTolFr: TColStd_HArray2OfReal, TwoDTolFr: TColStd_HArray2OfReal, ThreeDTolFr: TColStd_HArray2OfReal, FirstInU: float, LastInU: float, FirstInV: float, LastInV: float, FavorIso: GeomAbs_IsoType, ContInU: GeomAbs_Shape, ContInV: GeomAbs_Shape, PrecisCode: int, MaxDegInU: int, MaxDegInV: int, MaxPatch: int, Func: AdvApp2Var_EvaluatorFunc2Var, UChoice: AdvApprox_Cutting, VChoice: AdvApprox_Cutting) -> None: ...
	@overload
	def __init__(self, Num1DSS: int, Num2DSS: int, Num3DSS: int, OneDTol: TColStd_HArray1OfReal, TwoDTol: TColStd_HArray1OfReal, ThreeDTol: TColStd_HArray1OfReal, OneDTolFr: TColStd_HArray2OfReal, TwoDTolFr: TColStd_HArray2OfReal, ThreeDTolFr: TColStd_HArray2OfReal, FirstInU: float, LastInU: float, FirstInV: float, LastInV: float, FavorIso: GeomAbs_IsoType, ContInU: GeomAbs_Shape, ContInV: GeomAbs_Shape, PrecisCode: int, MaxDegInU: int, MaxDegInV: int, MaxPatch: int, Func: AdvApp2Var_EvaluatorFunc2Var, Crit: AdvApp2Var_Criterion, UChoice: AdvApprox_Cutting, VChoice: AdvApprox_Cutting) -> None: ...
	@overload
	def AverageError(self, Dimension: int) -> TColStd_HArray1OfReal: ...
	@overload
	def AverageError(self, Dimension: int, Index: int) -> float: ...
	def CritError(self, Dimension: int, Index: int) -> float: ...
	def HasResult(self) -> bool: ...
	def IsDone(self) -> bool: ...
	@overload
	def MaxError(self, Dimension: int) -> TColStd_HArray1OfReal: ...
	@overload
	def MaxError(self, Dimension: int, Index: int) -> float: ...
	def NumSubSpaces(self, Dimension: int) -> int: ...
	def Surface(self, Index: int) -> Geom_BSplineSurface: ...
	def UDegree(self) -> int: ...
	@overload
	def UFrontError(self, Dimension: int) -> TColStd_HArray1OfReal: ...
	@overload
	def UFrontError(self, Dimension: int, Index: int) -> float: ...
	def VDegree(self) -> int: ...
	@overload
	def VFrontError(self, Dimension: int) -> TColStd_HArray1OfReal: ...
	@overload
	def VFrontError(self, Dimension: int, Index: int) -> float: ...

class AdvApp2Var_ApproxF2var:
	pass

class AdvApp2Var_Context:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, ifav: int, iu: int, iv: int, nlimu: int, nlimv: int, iprecis: int, nb1Dss: int, nb2Dss: int, nb3Dss: int, tol1D: TColStd_HArray1OfReal, tol2D: TColStd_HArray1OfReal, tol3D: TColStd_HArray1OfReal, tof1D: TColStd_HArray2OfReal, tof2D: TColStd_HArray2OfReal, tof3D: TColStd_HArray2OfReal) -> None: ...
	def CToler(self) -> TColStd_HArray2OfReal: ...
	def FToler(self) -> TColStd_HArray2OfReal: ...
	def FavorIso(self) -> int: ...
	def IToler(self) -> TColStd_HArray1OfReal: ...
	def TotalDimension(self) -> int: ...
	def TotalNumberSSP(self) -> int: ...
	def UGauss(self) -> TColStd_HArray1OfReal: ...
	def UJacDeg(self) -> int: ...
	def UJacMax(self) -> TColStd_HArray1OfReal: ...
	def ULimit(self) -> int: ...
	def UOrder(self) -> int: ...
	def URoots(self) -> TColStd_HArray1OfReal: ...
	def VGauss(self) -> TColStd_HArray1OfReal: ...
	def VJacDeg(self) -> int: ...
	def VJacMax(self) -> TColStd_HArray1OfReal: ...
	def VLimit(self) -> int: ...
	def VOrder(self) -> int: ...
	def VRoots(self) -> TColStd_HArray1OfReal: ...

class AdvApp2Var_Criterion:
	def IsSatisfied(self, P: AdvApp2Var_Patch) -> bool: ...
	def MaxValue(self) -> float: ...
	def Repartition(self) -> AdvApp2Var_CriterionRepartition: ...
	def Type(self) -> AdvApp2Var_CriterionType: ...
	def Value(self, P: AdvApp2Var_Patch, C: AdvApp2Var_Context) -> None: ...

class AdvApp2Var_Data:
	@staticmethod
	def Getmaovpar() -> False: ...
	@staticmethod
	def Getmaovpch() -> False: ...
	@staticmethod
	def Getmdnombr() -> False: ...
	@staticmethod
	def Getminombr() -> False: ...
	@staticmethod
	def Getmlgdrtl() -> False: ...
	@staticmethod
	def Getmmapgs0() -> False: ...
	@staticmethod
	def Getmmapgs1() -> False: ...
	@staticmethod
	def Getmmapgs2() -> False: ...
	@staticmethod
	def Getmmapgss() -> False: ...
	@staticmethod
	def Getmmcmcnp() -> False: ...
	@staticmethod
	def Getmmjcobi() -> False: ...

class AdvApp2Var_Framework:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Frame: AdvApp2Var_SequenceOfNode, UFrontier: AdvApp2Var_SequenceOfStrip, VFrontier: AdvApp2Var_SequenceOfStrip) -> None: ...
	def ChangeIso(self, IndexIso: int, IndexStrip: int, anIso: AdvApp2Var_Iso) -> None: ...
	def FirstNode(self, Type: GeomAbs_IsoType, IndexIso: int, IndexStrip: int) -> int: ...
	def FirstNotApprox(self) -> Tuple[AdvApp2Var_Iso, int, int]: ...
	def IsoU(self, U: float, V0: float, V1: float) -> AdvApp2Var_Iso: ...
	def IsoV(self, U0: float, U1: float, V: float) -> AdvApp2Var_Iso: ...
	def LastNode(self, Type: GeomAbs_IsoType, IndexIso: int, IndexStrip: int) -> int: ...
	@overload
	def Node(self, IndexNode: int) -> AdvApp2Var_Node: ...
	@overload
	def Node(self, U: float, V: float) -> AdvApp2Var_Node: ...
	def UEquation(self, IndexIso: int, IndexStrip: int) -> TColStd_HArray1OfReal: ...
	def UpdateInU(self, CuttingValue: float) -> None: ...
	def UpdateInV(self, CuttingValue: float) -> None: ...
	def VEquation(self, IndexIso: int, IndexStrip: int) -> TColStd_HArray1OfReal: ...

class AdvApp2Var_MathBase:
	pass

class AdvApp2Var_Network:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, Net: AdvApp2Var_SequenceOfPatch, TheU: TColStd_SequenceOfReal, TheV: TColStd_SequenceOfReal) -> None: ...
	def ChangePatch(self, Index: int) -> AdvApp2Var_Patch: ...
	def FirstNotApprox(self) -> Tuple[bool, int]: ...
	def NbPatch(self) -> int: ...
	def NbPatchInU(self) -> int: ...
	def NbPatchInV(self) -> int: ...
	def Patch(self, UIndex: int, VIndex: int) -> AdvApp2Var_Patch: ...
	def SameDegree(self, iu: int, iv: int) -> Tuple[int, int]: ...
	def UParameter(self, Index: int) -> float: ...
	def UpdateInU(self, CuttingValue: float) -> None: ...
	def UpdateInV(self, CuttingValue: float) -> None: ...
	def VParameter(self, Index: int) -> float: ...

class AdvApp2Var_Node(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, iu: int, iv: int) -> None: ...
	@overload
	def __init__(self, UV: gp_XY, iu: int, iv: int) -> None: ...
	def Coord(self) -> gp_XY: ...
	def Error(self, iu: int, iv: int) -> float: ...
	def Point(self, iu: int, iv: int) -> gp_Pnt: ...
	def SetCoord(self, x1: float, x2: float) -> None: ...
	def SetError(self, iu: int, iv: int, error: float) -> None: ...
	def SetPoint(self, iu: int, iv: int, Pt: gp_Pnt) -> None: ...
	def UOrder(self) -> int: ...
	def VOrder(self) -> int: ...

class AdvApp2Var_Patch(Standard_Transient):
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, U0: float, U1: float, V0: float, V1: float, iu: int, iv: int) -> None: ...
	def AddConstraints(self, Conditions: AdvApp2Var_Context, Constraints: AdvApp2Var_Framework) -> None: ...
	def AddErrors(self, Constraints: AdvApp2Var_Framework) -> None: ...
	def AverageErrors(self) -> TColStd_HArray1OfReal: ...
	def ChangeDomain(self, a: float, b: float, c: float, d: float) -> None: ...
	def ChangeNbCoeff(self, NbCoeffU: int, NbCoeffV: int) -> None: ...
	def Coefficients(self, SSPIndex: int, Conditions: AdvApp2Var_Context) -> TColStd_HArray1OfReal: ...
	def CritValue(self) -> float: ...
	@overload
	def CutSense(self) -> int: ...
	@overload
	def CutSense(self, Crit: AdvApp2Var_Criterion, NumDec: int) -> int: ...
	def Discretise(self, Conditions: AdvApp2Var_Context, Constraints: AdvApp2Var_Framework, func: AdvApp2Var_EvaluatorFunc2Var) -> None: ...
	def HasResult(self) -> bool: ...
	def IsApproximated(self) -> bool: ...
	def IsDiscretised(self) -> bool: ...
	def IsoErrors(self) -> TColStd_HArray2OfReal: ...
	def MakeApprox(self, Conditions: AdvApp2Var_Context, Constraints: AdvApp2Var_Framework, NumDec: int) -> None: ...
	def MaxErrors(self) -> TColStd_HArray1OfReal: ...
	def NbCoeffInU(self) -> int: ...
	def NbCoeffInV(self) -> int: ...
	def OverwriteApprox(self) -> None: ...
	def Poles(self, SSPIndex: int, Conditions: AdvApp2Var_Context) -> TColgp_HArray2OfPnt: ...
	def ResetApprox(self) -> None: ...
	def SetCritValue(self, dist: float) -> None: ...
	def U0(self) -> float: ...
	def U1(self) -> float: ...
	def UOrder(self) -> int: ...
	def V0(self) -> float: ...
	def V1(self) -> float: ...
	def VOrder(self) -> int: ...

class AdvApp2Var_SysBase:
	def __init__(self) -> None: ...
	@staticmethod
	def do__fio() -> int: ...
	@staticmethod
	def do__lio() -> int: ...
	def mainial_(self) -> False: ...
	@staticmethod
	def mnfndeb_() -> int: ...

#classnotwrapped
class AdvApp2Var_EvaluatorFunc2Var: ...

#classnotwrapped
class AdvApp2Var_Iso: ...

# harray1 classes
# harray2 classes
# hsequence classes

AdvApp2Var_ApproxF2var_mma1her_ = AdvApp2Var_ApproxF2var.mma1her_
AdvApp2Var_ApproxF2var_mma2ac1_ = AdvApp2Var_ApproxF2var.mma2ac1_
AdvApp2Var_ApproxF2var_mma2ac2_ = AdvApp2Var_ApproxF2var.mma2ac2_
AdvApp2Var_ApproxF2var_mma2ac3_ = AdvApp2Var_ApproxF2var.mma2ac3_
AdvApp2Var_ApproxF2var_mma2can_ = AdvApp2Var_ApproxF2var.mma2can_
AdvApp2Var_ApproxF2var_mma2cdi_ = AdvApp2Var_ApproxF2var.mma2cdi_
AdvApp2Var_ApproxF2var_mma2ce1_ = AdvApp2Var_ApproxF2var.mma2ce1_
AdvApp2Var_ApproxF2var_mma2ds1_ = AdvApp2Var_ApproxF2var.mma2ds1_
AdvApp2Var_ApproxF2var_mma2fnc_ = AdvApp2Var_ApproxF2var.mma2fnc_
AdvApp2Var_ApproxF2var_mma2fx6_ = AdvApp2Var_ApproxF2var.mma2fx6_
AdvApp2Var_ApproxF2var_mma2jmx_ = AdvApp2Var_ApproxF2var.mma2jmx_
AdvApp2Var_ApproxF2var_mma2roo_ = AdvApp2Var_ApproxF2var.mma2roo_
AdvApp2Var_ApproxF2var_mmapptt_ = AdvApp2Var_ApproxF2var.mmapptt_
AdvApp2Var_Data_Getmaovpar = AdvApp2Var_Data.Getmaovpar
AdvApp2Var_Data_Getmaovpch = AdvApp2Var_Data.Getmaovpch
AdvApp2Var_Data_Getmdnombr = AdvApp2Var_Data.Getmdnombr
AdvApp2Var_Data_Getminombr = AdvApp2Var_Data.Getminombr
AdvApp2Var_Data_Getmlgdrtl = AdvApp2Var_Data.Getmlgdrtl
AdvApp2Var_Data_Getmmapgs0 = AdvApp2Var_Data.Getmmapgs0
AdvApp2Var_Data_Getmmapgs1 = AdvApp2Var_Data.Getmmapgs1
AdvApp2Var_Data_Getmmapgs2 = AdvApp2Var_Data.Getmmapgs2
AdvApp2Var_Data_Getmmapgss = AdvApp2Var_Data.Getmmapgss
AdvApp2Var_Data_Getmmcmcnp = AdvApp2Var_Data.Getmmcmcnp
AdvApp2Var_Data_Getmmjcobi = AdvApp2Var_Data.Getmmjcobi
AdvApp2Var_MathBase_mdsptpt_ = AdvApp2Var_MathBase.mdsptpt_
AdvApp2Var_MathBase_mmapcmp_ = AdvApp2Var_MathBase.mmapcmp_
AdvApp2Var_MathBase_mmaperx_ = AdvApp2Var_MathBase.mmaperx_
AdvApp2Var_MathBase_mmarcin_ = AdvApp2Var_MathBase.mmarcin_
AdvApp2Var_MathBase_mmbulld_ = AdvApp2Var_MathBase.mmbulld_
AdvApp2Var_MathBase_mmcdriv_ = AdvApp2Var_MathBase.mmcdriv_
AdvApp2Var_MathBase_mmcglc1_ = AdvApp2Var_MathBase.mmcglc1_
AdvApp2Var_MathBase_mmcvctx_ = AdvApp2Var_MathBase.mmcvctx_
AdvApp2Var_MathBase_mmcvinv_ = AdvApp2Var_MathBase.mmcvinv_
AdvApp2Var_MathBase_mmdrc11_ = AdvApp2Var_MathBase.mmdrc11_
AdvApp2Var_MathBase_mmdrvck_ = AdvApp2Var_MathBase.mmdrvck_
AdvApp2Var_MathBase_mmeps1_ = AdvApp2Var_MathBase.mmeps1_
AdvApp2Var_MathBase_mmfmca8_ = AdvApp2Var_MathBase.mmfmca8_
AdvApp2Var_MathBase_mmfmca9_ = AdvApp2Var_MathBase.mmfmca9_
AdvApp2Var_MathBase_mmfmcar_ = AdvApp2Var_MathBase.mmfmcar_
AdvApp2Var_MathBase_mmfmcb5_ = AdvApp2Var_MathBase.mmfmcb5_
AdvApp2Var_MathBase_mmfmtb1_ = AdvApp2Var_MathBase.mmfmtb1_
AdvApp2Var_MathBase_mmhjcan_ = AdvApp2Var_MathBase.mmhjcan_
AdvApp2Var_MathBase_mminltt_ = AdvApp2Var_MathBase.mminltt_
AdvApp2Var_MathBase_mmjacan_ = AdvApp2Var_MathBase.mmjacan_
AdvApp2Var_MathBase_mmjaccv_ = AdvApp2Var_MathBase.mmjaccv_
AdvApp2Var_MathBase_mmmpocur_ = AdvApp2Var_MathBase.mmmpocur_
AdvApp2Var_MathBase_mmmrslwd_ = AdvApp2Var_MathBase.mmmrslwd_
AdvApp2Var_MathBase_mmpobas_ = AdvApp2Var_MathBase.mmpobas_
AdvApp2Var_MathBase_mmpocrb_ = AdvApp2Var_MathBase.mmpocrb_
AdvApp2Var_MathBase_mmposui_ = AdvApp2Var_MathBase.mmposui_
AdvApp2Var_MathBase_mmresol_ = AdvApp2Var_MathBase.mmresol_
AdvApp2Var_MathBase_mmrtptt_ = AdvApp2Var_MathBase.mmrtptt_
AdvApp2Var_MathBase_mmsrre2_ = AdvApp2Var_MathBase.mmsrre2_
AdvApp2Var_MathBase_mmtrpjj_ = AdvApp2Var_MathBase.mmtrpjj_
AdvApp2Var_MathBase_mmunivt_ = AdvApp2Var_MathBase.mmunivt_
AdvApp2Var_MathBase_mmveps3_ = AdvApp2Var_MathBase.mmveps3_
AdvApp2Var_MathBase_mmvncol_ = AdvApp2Var_MathBase.mmvncol_
AdvApp2Var_MathBase_mmwprcs_ = AdvApp2Var_MathBase.mmwprcs_
AdvApp2Var_MathBase_msc_ = AdvApp2Var_MathBase.msc_
AdvApp2Var_MathBase_mvsheld_ = AdvApp2Var_MathBase.mvsheld_
AdvApp2Var_MathBase_mzsnorm_ = AdvApp2Var_MathBase.mzsnorm_
AdvApp2Var_MathBase_pow__di = AdvApp2Var_MathBase.pow__di
AdvApp2Var_SysBase_do__fio = AdvApp2Var_SysBase.do__fio
AdvApp2Var_SysBase_do__lio = AdvApp2Var_SysBase.do__lio
AdvApp2Var_SysBase_macinit_ = AdvApp2Var_SysBase.macinit_
AdvApp2Var_SysBase_maermsg_ = AdvApp2Var_SysBase.maermsg_
AdvApp2Var_SysBase_maitbr8_ = AdvApp2Var_SysBase.maitbr8_
AdvApp2Var_SysBase_maovsr8_ = AdvApp2Var_SysBase.maovsr8_
AdvApp2Var_SysBase_mcrfill_ = AdvApp2Var_SysBase.mcrfill_
AdvApp2Var_SysBase_mgenmsg_ = AdvApp2Var_SysBase.mgenmsg_
AdvApp2Var_SysBase_mgsomsg_ = AdvApp2Var_SysBase.mgsomsg_
AdvApp2Var_SysBase_miraz_ = AdvApp2Var_SysBase.miraz_
AdvApp2Var_SysBase_mnfndeb_ = AdvApp2Var_SysBase.mnfndeb_
AdvApp2Var_SysBase_msifill_ = AdvApp2Var_SysBase.msifill_
AdvApp2Var_SysBase_msrfill_ = AdvApp2Var_SysBase.msrfill_
AdvApp2Var_SysBase_mswrdbg_ = AdvApp2Var_SysBase.mswrdbg_
AdvApp2Var_SysBase_mvriraz_ = AdvApp2Var_SysBase.mvriraz_



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.Geom2d import *
from OCC.Core.math import *
from OCC.Core.TColgp import *
from OCC.Core.TColStd import *


class FairCurve_AnalysisCode(IntEnum):
	FairCurve_OK: int = ...
	FairCurve_NotConverged: int = ...
	FairCurve_InfiniteSliding: int = ...
	FairCurve_NullHeight: int = ...
FairCurve_OK = FairCurve_AnalysisCode.FairCurve_OK
FairCurve_NotConverged = FairCurve_AnalysisCode.FairCurve_NotConverged
FairCurve_InfiniteSliding = FairCurve_AnalysisCode.FairCurve_InfiniteSliding
FairCurve_NullHeight = FairCurve_AnalysisCode.FairCurve_NullHeight

class FairCurve_Batten:
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d, Height: float, Slope: Optional[float] = 0) -> None: ...
	def Compute(self, NbIterations: Optional[int] = 50, Tolerance: Optional[float] = 1.0e-3) -> Tuple[bool, FairCurve_AnalysisCode]: ...
	def Curve(self) -> Geom2d_BSplineCurve: ...
	def GetAngle1(self) -> float: ...
	def GetAngle2(self) -> float: ...
	def GetConstraintOrder1(self) -> int: ...
	def GetConstraintOrder2(self) -> int: ...
	def GetFreeSliding(self) -> bool: ...
	def GetHeight(self) -> float: ...
	def GetP1(self) -> gp_Pnt2d: ...
	def GetP2(self) -> gp_Pnt2d: ...
	def GetSlidingFactor(self) -> float: ...
	def GetSlope(self) -> float: ...
	def SetAngle1(self, Angle1: float) -> None: ...
	def SetAngle2(self, Angle2: float) -> None: ...
	def SetConstraintOrder1(self, ConstraintOrder: int) -> None: ...
	def SetConstraintOrder2(self, ConstraintOrder: int) -> None: ...
	def SetFreeSliding(self, FreeSliding: bool) -> None: ...
	def SetHeight(self, Height: float) -> None: ...
	def SetP1(self, P1: gp_Pnt2d) -> None: ...
	def SetP2(self, P2: gp_Pnt2d) -> None: ...
	def SetSlidingFactor(self, SlidingFactor: float) -> None: ...
	def SetSlope(self, Slope: float) -> None: ...
	def SlidingOfReference(self) -> float: ...

class FairCurve_BattenLaw(math_Function):
	def __init__(self, Heigth: float, Slope: float, Sliding: float) -> None: ...
	def SetHeigth(self, Heigth: float) -> None: ...
	def SetSliding(self, Sliding: float) -> None: ...
	def SetSlope(self, Slope: float) -> None: ...
	def Value(self, T: float) -> Tuple[bool, float]: ...

class FairCurve_DistributionOfEnergy(math_FunctionSet):
	def NbEquations(self) -> int: ...
	def NbVariables(self) -> int: ...
	def SetDerivativeOrder(self, DerivativeOrder: int) -> None: ...

class FairCurve_Energy(math_MultipleVarFunctionWithHessian):
	def Gradient(self, X: math_Vector, G: math_Vector) -> bool: ...
	def NbVariables(self) -> int: ...
	def Poles(self) -> TColgp_HArray1OfPnt2d: ...
	def Value(self, X: math_Vector) -> Tuple[bool, float]: ...
	@overload
	def Values(self, X: math_Vector, G: math_Vector) -> Tuple[bool, float]: ...
	@overload
	def Values(self, X: math_Vector, G: math_Vector, H: math_Matrix) -> Tuple[bool, float]: ...
	def Variable(self, X: math_Vector) -> bool: ...

class FairCurve_Newton(math_NewtonMinimum):
	def __init__(self, theFunction: math_MultipleVarFunctionWithHessian, theSpatialTolerance: Optional[float] = 1.0e-7, theCriteriumTolerance: Optional[float] = 1.0e-7, theNbIterations: Optional[int] = 40, theConvexity: Optional[float] = 1.0e-6, theWithSingularity: Optional[bool] = True) -> None: ...
	def IsConverged(self) -> bool: ...

class FairCurve_DistributionOfJerk(FairCurve_DistributionOfEnergy):
	def __init__(self, BSplOrder: int, FlatKnots: TColStd_HArray1OfReal, Poles: TColgp_HArray1OfPnt2d, DerivativeOrder: int, Law: FairCurve_BattenLaw, NbValAux: Optional[int] = 0) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...

class FairCurve_DistributionOfSagging(FairCurve_DistributionOfEnergy):
	def __init__(self, BSplOrder: int, FlatKnots: TColStd_HArray1OfReal, Poles: TColgp_HArray1OfPnt2d, DerivativeOrder: int, Law: FairCurve_BattenLaw, NbValAux: Optional[int] = 0) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...

class FairCurve_DistributionOfTension(FairCurve_DistributionOfEnergy):
	def __init__(self, BSplOrder: int, FlatKnots: TColStd_HArray1OfReal, Poles: TColgp_HArray1OfPnt2d, DerivativeOrder: int, LengthSliding: float, Law: FairCurve_BattenLaw, NbValAux: Optional[int] = 0, Uniform: Optional[bool] = False) -> None: ...
	def SetLengthSliding(self, LengthSliding: float) -> None: ...
	def Value(self, X: math_Vector, F: math_Vector) -> bool: ...

class FairCurve_EnergyOfBatten(FairCurve_Energy):
	def __init__(self, BSplOrder: int, FlatKnots: TColStd_HArray1OfReal, Poles: TColgp_HArray1OfPnt2d, ContrOrder1: int, ContrOrder2: int, Law: FairCurve_BattenLaw, LengthSliding: float, FreeSliding: Optional[bool] = True, Angle1: Optional[float] = 0, Angle2: Optional[float] = 0) -> None: ...
	def LengthSliding(self) -> float: ...
	def Status(self) -> FairCurve_AnalysisCode: ...
	def Variable(self, X: math_Vector) -> bool: ...

class FairCurve_EnergyOfMVC(FairCurve_Energy):
	def __init__(self, BSplOrder: int, FlatKnots: TColStd_HArray1OfReal, Poles: TColgp_HArray1OfPnt2d, ContrOrder1: int, ContrOrder2: int, Law: FairCurve_BattenLaw, PhysicalRatio: float, LengthSliding: float, FreeSliding: Optional[bool] = True, Angle1: Optional[float] = 0, Angle2: Optional[float] = 0, Curvature1: Optional[float] = 0, Curvature2: Optional[float] = 0) -> None: ...
	def LengthSliding(self) -> float: ...
	def Status(self) -> FairCurve_AnalysisCode: ...
	def Variable(self, X: math_Vector) -> bool: ...

class FairCurve_MinimalVariation(FairCurve_Batten):
	def __init__(self, P1: gp_Pnt2d, P2: gp_Pnt2d, Heigth: float, Slope: Optional[float] = 0, PhysicalRatio: Optional[float] = 0) -> None: ...
	def Compute(self, NbIterations: Optional[int] = 50, Tolerance: Optional[float] = 1.0e-3) -> Tuple[bool, FairCurve_AnalysisCode]: ...
	def GetCurvature1(self) -> float: ...
	def GetCurvature2(self) -> float: ...
	def GetPhysicalRatio(self) -> float: ...
	def SetCurvature1(self, Curvature: float) -> None: ...
	def SetCurvature2(self, Curvature: float) -> None: ...
	def SetPhysicalRatio(self, Ratio: float) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

